/***************************************************************
* L&L - Labyrinths & Legends
* Copyright (c) 1993-2004 YOSHIMURA Tomohiko All rights reserved.
* 
* Created by BowKenKen
*   URL: https://sourceforge.jp/projects/lnl/
* 
* License is GPL
* 
* ܥץϥե꡼եȥǤ
* ʤϡ Free Software Foundation ɽ
*  GNU ̸ͭѵΡ֥С󣲡
* ϤʹߤγƥС椫餤줫򤷡
* ΥС˽äܥץ
* ۤޤѹ뤳ȤǤޤ
* 
* ܥץͭѤȤϻפޤۤˤäƤϡ
* ԾڤŪŬˤĤƤΰۤݾڤޤ,
* ʤݾڤԤʤޤ
* ܺ٤ˤĤƤ GNU ̸ͭѵɤߤ
* 
* ʤϡܥץȰ GNU ̸ͭѵ
* μ̤äƤϤǤǤʤϡ
*   Free Software Foundation, Inc.,
*   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
* ؼ񤤤Ƥ
* 
* $Id: misc.h,v 1.12 2004/12/08 01:50:21 bowkenken Exp $
***************************************************************/

#ifndef	MISC_H
#define	MISC_H

#define	FLG_NULL	0

#define	FIGURE_MAX_N	10	/* κ */

/* ޥå׾δ */

#define	FACE_MJR_NULL	' '
#define	FACE_MNR_NULL	' '
#define	FACE_MJR_ERR	'?'
#define	FACE_MNR_ERR	'?'

/* ̵¥롼ɻѤκ롼׿ */

#define	LOOP_MAX_100	128
#define	LOOP_MAX_200	256
#define	LOOP_MAX_1000	1024
#define	LOOP_MAX_4000	4096
#define	LOOP_MAX_10000	10240

/* ֡ꥢ */

typedef char	bool_t;
#ifndef	FALSE
# define	FALSE	0
#endif	/* FALSE */
#ifndef	TRUE
# define	TRUE	1
#endif	/* TRUE */

/* ɴʬΨ(%) */

typedef long	rate_t;
#define	_100_PERCENT	((rate_t)100)	/* 100% */
#define	MODIFIED_MIN_RATE	1	/* ͤκǾ */

/* Ψ(N:M) */

typedef long	ratio_t;

/* ɸ */

typedef struct {
	long	x, y;
} pos_t;

/*  */

typedef long	gold_t;
#define	GOLD_MAX	999999999

/* С */

typedef struct {
	long	mjr, mnr, pat;
} ver_t;

#endif	/* MISC_H */
